"use strict";

var _interopRequireWildcard = require("@babel/runtime/helpers/interopRequireWildcard");

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.getDerivedTypes = getDerivedTypes;
exports.getSimilarTypes = getSimilarTypes;

var _class = require("./class");

var _create = require("../../codec/create");

var _AbstractInt = _interopRequireDefault(require("../../codec/AbstractInt"));

var _Vec = _interopRequireDefault(require("../../codec/Vec"));

var _formatting = require("./formatting");

var _imports = require("./imports");

var primitiveClasses = _interopRequireWildcard(require("../../primitive"));

// Copyright 2017-2019 @polkadot/types authors & contributors
// This software may be modified and distributed under the terms
// of the Apache-2.0 license. See the LICENSE file for details.
// From `T`, generate `Compact<T>, Option<T>, Vec<T>`
function getDerivedTypes(type, primitiveName, imports) {
  // `primitiveName` represents the actual primitive type our type is mapped to
  const isCompact = (0, _class.isCompactEncodable)(primitiveClasses[primitiveName]);
  (0, _imports.setImports)(imports, ['Option', 'Vec', isCompact ? 'Compact' : '']);
  return ["".concat(type, ": ").concat(type, ";"), isCompact ? "'".concat((0, _formatting.formatCompact)(type), "': ").concat((0, _formatting.formatCompact)(type), ";") : '', "'".concat((0, _formatting.formatOption)(type), "': ").concat((0, _formatting.formatOption)(type), ";"), "'".concat((0, _formatting.formatVec)(type), "': ").concat((0, _formatting.formatVec)(type), ";")].filter(x => !!x);
} // Make types a little bit more flexible
// - if param instanceof AbstractInt, then param: u64 | Uint8array | string | number
// etc


function getSimilarTypes(type, imports) {
  const possibleTypes = [type];

  if (type === 'Extrinsic') {
    (0, _imports.setImports)(imports, ['IExtrinsic']);
    return ['IExtrinsic'];
  }

  if ((0, _class.isChildClass)(_Vec.default, (0, _create.ClassOfUnsafe)(type))) {
    return ["(".concat(getSimilarTypes((0, _create.getTypeDef)(type).sub.type, imports).join(' | '), ")[]")];
  } // FIXME This is a hack, it's hard to correctly type StorageKeys in the
  // current state


  if (type === 'StorageKey') {
    return ['any'];
  } // Cannot get isChildClass of abstract class, but it works


  if ((0, _class.isChildClass)(_AbstractInt.default, (0, _create.ClassOfUnsafe)(type))) {
    possibleTypes.push('Uint8Array', 'number', 'string');
  } else if ((0, _class.isChildClass)(Uint8Array, (0, _create.ClassOfUnsafe)(type))) {
    possibleTypes.push('Uint8Array', 'string');
  } else if ((0, _class.isChildClass)(String, (0, _create.ClassOfUnsafe)(type))) {
    possibleTypes.push('string');
  }

  return possibleTypes;
}